==> DatabionicSwarm_0.9.7.tar.gz: DatabionicSwarm/R/plotSwarm.R <==
plotSwarm=function(Points,Cls=rep(1,nrow(Points)),xlab='X',ylab='Y',main="DataBots"){
  X=Points[,1]
  Y=Points[,2]
    #ColorSymbSequence <- DefaultColorSymbSequence()
    PlotSymbol <- 20#ColorSymbSequence[1]
  
    #DefaultColorSeq <- DefaultColorSequence()
    # if (missing(ColorSequence))
      ColorSequence <- c("green", "blue", "magenta", "cyan", "black", "yellow", "red", 
                         "burlywood4", "gray28", "darksalmon", "orchid2", "plum4", "gray41", 
                         "plum", "pink1", "coral1", "gray39", "gray", "gray67", "slategray1", 
                         "peachpuff1", "floralwhite", "hotpink", "gray12", "gray88", "orange1", 
                         "rosybrown1", "royalblue", "gray78", "mediumturquoise", "darkolivegreen", 
                         "gray45", "azure", "peachpuff3", "hotpink3", "blue1", "chocolate1", 
                         "tomato", "lightyellow", "gainsboro", "steelblue1", "gray95", 
                         "blue4", "slategrey", "violet", "mistyrose3", "orchid4", "lavenderblush1", 
                         "olivedrab2", "gray54", "gray74", "lemonchiffon4", "blue2", "yellow", 
                         "gray31", "goldenrod1", "lightyellow2", "honeydew", "gray84", 
                         "gray82", "orangered4", "chocolate4", "gray60", "palevioletred", 
                         "darkgray", "moccasin", "firebrick1", "palegreen", "goldenrod2", 
                         "ivory3", "seagreen4", "salmon1", "khaki1", "gray46", "lightgoldenrodyellow", 
                         "lightsalmon", "springgreen4", "gray13", "gray24", "lightyellow4", 
                         "slateblue2", "orchid", "darkslategray3", "coral2", "palegreen4", 
                         "palevioletred3", "gray15", "salmon3", "mediumaquamarine", "maroon", 
                         "thistle2", "gray23", "mediumorchid3", "lightgoldenrod1", "seashell3", 
                         "lightskyblue2", "lightsteelblue", "lavenderblush", "tan2", "gray5", 
                         "darkslategray2", "chocolate", "mintcream", "lightsteelblue3", 
                         "red3", "indianred1", "chartreuse1", "chocolate3", "skyblue", 
                         "brown4", "sandybrown", "honeydew4", "gold", "white", "lightsalmon1", 
                         "deepskyblue2", "skyblue3", "palegoldenrod", "seagreen1", "darkred", 
                         "lightgoldenrod4", "ivory4", "palegreen3", "violetred2", "navajowhite2", 
                         "olivedrab", "skyblue1", "lemonchiffon1", "ivory2", "forestgreen", 
                         "lightsalmon2", "palevioletred2", "gray49", "honeydew1", "lightblue", 
                         "darkolivegreen2", "violetred3", "gray27", "darkolivegreen1", 
                         "steelblue4", "navajowhite3", "gray91", "salmon", "darkorchid3", 
                         "green", "paleturquoise4", "magenta", "gold4", "gray53", "limegreen", 
                         "gray43", "mediumorchid4", "lightblue2", "lightcoral", "mediumorchid1", 
                         "tan4", "dimgray", "yellow2", "skyblue2", "mediumorchid", "deeppink4", 
                         "snow3", "cyan", "tomato4", "magenta4", "mediumpurple3", "aquamarine1", 
                         "plum3", "slategray3", "antiquewhite1", "lightblue1", "mediumblue", 
                         "gray10", "gray72", "turquoise3", "gray29", "lightsalmon3", "deepskyblue1", 
                         "cyan1", "violetred", "deepskyblue", "cyan2", "brown2", "gray0", 
                         "palevioletred1", "gray98", "lemonchiffon", "lavenderblush3", 
                         "chartreuse2", "turquoise", "gray89", "gray11", "steelblue2", 
                         "deepskyblue3", "darkseagreen1", "gray18", "navajowhite4", "lightslategray", 
                         "gray68", "tan", "royalblue1", "brown", "royalblue2", "gray66", 
                         "green4", "antiquewhite4", "gray16", "gray21", "gray94", "orange4", 
                         "aquamarine", "firebrick2", "gray76", "cadetblue3", "slateblue", 
                         "gray99", "gray30", "rosybrown4", "olivedrab4", "lightgoldenrod", 
                         "darkorchid4", "slategray", "red", "gray69", "khaki2", "lightsteelblue4", 
                         "midnightblue", "palevioletred4", "honeydew2", "mediumpurple4", 
                         "gray17", "green2", "gold1", "darkkhaki", "darkviolet", "snow1", 
                         "lightskyblue1", "orange", "seagreen3", "khaki4", "gray47", "gray85", 
                         "cornflowerblue", "lightblue4", "turquoise1", "gray4", "gray44", 
                         "purple1", "darkolivegreen4", "darkolivegreen3", "darkorange3", 
                         "snow2", "peru", "gray93", "goldenrod3", "maroon1", "wheat3", 
                         "mediumpurple1", "dodgerblue2", "plum2", "antiquewhite2", "powderblue", 
                         "deeppink", "darkslategray1", "turquoise2", "maroon3", "brown3", 
                         "darkgoldenrod", "gray80", "pink3", "darkorange1", "azure4", 
                         "seagreen", "gold2", "gray71", "olivedrab3", "seashell2", "oldlace", 
                         "cyan3", "lightsalmon4", "olivedrab1", "gray32", "lemonchiffon3", 
                         "greenyellow", "lightcyan", "gray56", "mistyrose", "seashell4", 
                         "seashell1", "lightcyan4", "tomato1", "lightskyblue4", "azure2", 
                         "darkseagreen", "ivory1", "linen", "darkblue", "deeppink3", "whitesmoke", 
                         "gray40", "gray9", "darkgoldenrod4", "lightgray", "chartreuse", 
                         "gray97", "cadetblue1", "lightgrey", "aquamarine2", "mediumseagreen", 
                         "gray7", "gray36", "gray1", "lemonchiffon2", "hotpink1", "red2", 
                         "ivory", "lightblue3", "darkslategray4", "lightseagreen", "lightslateblue", 
                         "mistyrose1", "lightskyblue", "papayawhip", "darkorange2", "salmon2", 
                         "yellow4", "mistyrose4", "cornsilk1", "lightskyblue3", "darkgoldenrod3", 
                         "thistle1", "paleturquoise1", "sienna", "darkorchid", "khaki", 
                         "gray50", "gray26", "blanchedalmond", "gray62", "cornsilk3", 
                         "darkgoldenrod2", "gray63", "mediumpurple", "pink4", "gray90", 
                         "darkorchid2", "gray57", "turquoise4", "indianred", "sienna2", 
                         "darkmagenta", "green1", "springgreen1", "violetred1", "indianred3", 
                         "gray48", "deeppink2", "gray33", "slategray2", "burlywood2", 
                         "ghostwhite", "azure1", "yellowgreen", "chocolate2", "springgreen", 
                         "cornsilk4", "darkturquoise", "darkorange4", "pink2", "lightpink3", 
                         "navajowhite", "sienna1", "lightyellow1", "tan1", "gray20", "peachpuff", 
                         "darkgreen", "magenta3", "maroon4", "purple4", "gray34", "gray52", 
                         "gold3", "springgreen2", "orangered", "orangered2", "darkgrey", 
                         "orangered1", "burlywood3", "brown1", "lightcyan1", "mediumspringgreen", 
                         "dodgerblue3", "darkcyan", "firebrick3", "sienna4", "seashell", 
                         "mediumvioletred", "sienna3", "tomato3", "tan3", "slateblue1", 
                         "lightgoldenrod3", "red4", "firebrick4", "gray55", "navy", "darkslategray", 
                         "darkseagreen4", "lightgreen", "aquamarine3", "darkorange", "lightgoldenrod2", 
                         "gray92", "gray79", "saddlebrown", "darkseagreen3", "navyblue", 
                         "snow4", "blue3", "skyblue4", "gray86", "hotpink2", "magenta2", 
                         "paleturquoise2", "yellow3", "steelblue", "aquamarine4", "gray61", 
                         "mistyrose2", "beige", "lightyellow3", "lightcyan2", "maroon2", 
                         "cyan4", "honeydew3", "gray81", "snow", "gray75", "darkseagreen2", 
                         "rosybrown", "gray87", "gray65", "orchid1", "lightsteelblue2", 
                         "cadetblue", "cornsilk2", "gray58", "lightpink2", "paleturquoise", 
                         "wheat", "khaki3", "aliceblue", "plum1", "gray51", "gray25", 
                         "royalblue4", "chartreuse4", "gray59", "mediumpurple2", "bisque1", 
                         "gray35", "tomato2", "navajowhite1", "cadetblue2", "goldenrod", 
                         "darkgoldenrod1", "gray14", "pink", "orangered3", "lightsteelblue1", 
                         "black", "salmon4", "dimgrey", "lavenderblush4", "bisque", "mediumslateblue", 
                         "gray73", "peachpuff2", "gray64", "slateblue3", "gray8", "gray6", 
                         "cadetblue4", "wheat1", "springgreen3", "indianred2", "lightpink4", 
                         "lavenderblush2", "yellow1", "azure3", "goldenrod4", "gray37", 
                         "cornsilk", "paleturquoise3", "mediumorchid2", "darkslateblue", 
                         "indianred4", "gray100", "antiquewhite3", "coral4", "lightpink", 
                         "slateblue4", "slategray4", "orange3", "firebrick", "lightcyan3", 
                         "purple2", "orange2", "antiquewhite", "gray2", "darkorchid1", 
                         "darkslategrey", "chartreuse3", "bisque4", "gray70", "dodgerblue4", 
                         "coral3", "gray96", "gray19", "seagreen2", "bisque2", "violetred4", 
                         "thistle4", "wheat2", "rosybrown3", "blue", "gray22", "orchid3", 
                         "coral", "steelblue3", "hotpink4", "wheat4", "gray83", "red1", 
                         "blueviolet", "magenta1", "gray77", "lightslategrey", "dodgerblue", 
                         "royalblue3", "burlywood1", "dodgerblue1", "lavender", "thistle", 
                         "burlywood", "green3", "deeppink1", "purple3", "lawngreen", "peachpuff4", 
                         "deepskyblue4", "purple", "bisque3", "palegreen2", "thistle3", 
                         "gray42", "gray38", "lightpink1", "palegreen1", "gray3", "rosybrown2"
      )
      NormalizeCls_hlp <- function(Cls) {
        #E<-NormalizeCls(Cls);
        #NormalizedCls    <- E$normalizedCls      #    Cls consistently recoded to positive consecutive integers
        #NormalizedClasses<- E$normalizedClasses  #    the different class numbers in NormalizedCls
        #UniqueCls        <- E$uniqueClasses      #    the different class numbers in Cls such that 
        #AnzClasses       <- E$numberOfClasses    #    the number of different classes
        # 
        # Values in Cls are consistently recoded to positive consecutive integers
        # INPUT
        # Cls                  vector of class identifiers can be integers or
        #                      NaN's, need not be consecutive nor positive
        # OUTPUT list of 
        # normalizedCls           Cls consistently recoded to positive consecutive integers
        # normalizedClasses        the different class numbers in NormalizedCls
        # uniqueClasses            the different class numbers in Cls such that 
        #                           NormalizedCls(i) <-> UniqueCls(i)
        # numberOfClasses           the number of different classes
        
        # ALU 2014
        # 1.Editor:MT 2016
        
        uniqueClasses <- sort(na.last=T,unique(Cls))
        numberOfClasses <- length(uniqueClasses)
        unique2Cls <- NULL #  initializing the vector
        
        for (i in 1:length(Cls) ) { # calculating the indexes of elements of Cls in uniqueClasses
          unique2Cls <- c( unique2Cls, which(uniqueClasses == Cls[i]))
        } 
        
        if (numberOfClasses > 0) {
          normalizedClasses <- c(1: numberOfClasses)
          normalizedCls <- normalizedClasses[unique2Cls]
        }
        else {
          normalizedClasses <- Cls
        }
        
        return(list(normalizedCls = normalizedCls, normalizedClasses = normalizedClasses, uniqueClasses = uniqueClasses, numberOfClasses = numberOfClasses))
      }
    E <- NormalizeCls_hlp(Cls)
    NormalizedCls <- E$normalizedCls
    UniqueCls <- E$uniqueClasses
    AnzClasses <- E$numberOfClasses
  
  
    AnzColors = length(ColorSequence)
    ColorNR = c(1:AnzColors)
    if (AnzClasses > AnzColors) {
      ColorNR = (c(0:AnzClasses)%%AnzColors) + 1
    }
    MinX = min(X,na.rm=T)
    MaxX = max(X,na.rm=T)
    MinY = min(Y,na.rm=T)
    MaxY = max(Y,na.rm=T)
    xlim=c((MinX-abs(0.1*MinX)),(MaxX+abs(0.1*MaxX)))
    ylim=c((MinY-abs(0.1*MinY)),(MaxY+abs(0.1*MaxY)))
  
  #Initialisierungsplot
  plot.new()
  #par(usr=c(MinX,MaxX,MinY,MaxY))
  par(usr=c(xlim,ylim))
  par(xaxs='i')
  par(yaxs='i')
  # Plot der Punkte
    for (i in 1:AnzClasses) {
      C = UniqueCls[i]
      Ind = which(C == NormalizedCls)
      points(X[Ind], Y[Ind], pch = PlotSymbol,
             col = ColorSequence[ColorNR[i]], new = TRUE)
    }
  
  axis(1,xlim=xlim,col="black",las=1) #x-Achse
  axis(2,ylim=ylim,col="black",las=1) #y-Achse
  title(xlab=xlab,ylab=ylab,main=main)
  box()
}

==> DatabionicSwarm_1.2.1.tar.gz: DatabionicSwarm/R/plotSwarm.R <==
plotSwarm=function(Points,Cls=rep(1,nrow(Points)),xlab='X',ylab='Y',main="DataBots"){
  X=Points[,1]
  Y=Points[,2]
    #ColorSymbSequence <- DefaultColorSymbSequence()
    PlotSymbol <- 20#ColorSymbSequence[1]
  
    #DefaultColorSeq <- DefaultColorSequence()
    # if (missing(ColorSequence))
    ColorSequence <- DatabionicSwarm::DefaultColorSequence
      
      NormalizeCls_hlp <- function(Cls) {
        #E<-NormalizeCls(Cls);
        #NormalizedCls    <- E$normalizedCls      #    Cls consistently recoded to positive consecutive integers
        #NormalizedClasses<- E$normalizedClasses  #    the different class numbers in NormalizedCls
        #UniqueCls        <- E$uniqueClasses      #    the different class numbers in Cls such that 
        #AnzClasses       <- E$numberOfClasses    #    the number of different classes
        # 
        # Values in Cls are consistently recoded to positive consecutive integers
        # INPUT
        # Cls                  vector of class identifiers can be integers or
        #                      NaN's, need not be consecutive nor positive
        # OUTPUT list of 
        # normalizedCls           Cls consistently recoded to positive consecutive integers
        # normalizedClasses        the different class numbers in NormalizedCls
        # uniqueClasses            the different class numbers in Cls such that 
        #                           NormalizedCls(i) <-> UniqueCls(i)
        # numberOfClasses           the number of different classes
        
        # ALU 2014
        # 1.Editor:MT 2016
        
        uniqueClasses <- sort(na.last=T,unique(Cls))
        numberOfClasses <- length(uniqueClasses)
        unique2Cls <- NULL #  initializing the vector
        
        for (i in 1:length(Cls) ) { # calculating the indexes of elements of Cls in uniqueClasses
          unique2Cls <- c( unique2Cls, which(uniqueClasses == Cls[i]))
        } 
        
        if (numberOfClasses > 0) {
          normalizedClasses <- c(1: numberOfClasses)
          normalizedCls <- normalizedClasses[unique2Cls]
        }
        else {
          normalizedClasses <- Cls
        }
        
        return(list(normalizedCls = normalizedCls, normalizedClasses = normalizedClasses, uniqueClasses = uniqueClasses, numberOfClasses = numberOfClasses))
      }
    E <- NormalizeCls_hlp(Cls)
    NormalizedCls <- E$normalizedCls
    UniqueCls <- E$uniqueClasses
    AnzClasses <- E$numberOfClasses
  
  
    AnzColors = length(ColorSequence)
    ColorNR = c(1:AnzColors)
    if (AnzClasses > AnzColors) {
      ColorNR = (c(0:AnzClasses)%%AnzColors) + 1
    }
    MinX = min(X,na.rm=T)
    MaxX = max(X,na.rm=T)
    MinY = min(Y,na.rm=T)
    MaxY = max(Y,na.rm=T)
    xlim=c((MinX-abs(0.1*MinX)),(MaxX+abs(0.1*MaxX)))
    ylim=c((MinY-abs(0.1*MinY)),(MaxY+abs(0.1*MaxY)))
  
  #Initialisierungsplot
  plot.new()
  #par(usr=c(MinX,MaxX,MinY,MaxY))
  par(usr=c(xlim,ylim))
  par(xaxs='i')
  par(yaxs='i')
  # Plot der Punkte
    for (i in 1:AnzClasses) {
      C = UniqueCls[i]
      Ind = which(C == NormalizedCls)
      points(X[Ind], Y[Ind], pch = PlotSymbol,
             col = ColorSequence[ColorNR[i]], new = TRUE)
    }
  
  axis(1,xlim=xlim,col="black",las=1) #x-Achse
  axis(2,ylim=ylim,col="black",las=1) #y-Achse
  title(xlab=xlab,ylab=ylab,main=main)
  box()
}
